//---------------------------------------------------------------------\\
//   ___            _                _ __    _ __                      \\
//  / __|    __    | |_     _  _    | '_ \  | '_ \   ___    _ _        \\
//  \__ \   / _|   | ' \   | +| |   | .__/  | .__/  / -_)  | ' \       \\
//  |___/   \__|_  |_||_|   \_,_|   |_|__   |_|__   \___|  |_||_|      \\
//---------------------------------------------------------------------\\
//-----| Copyright (c) 2013 Fredrik Kaupang (Kaupang Studios, Inc) |---\\
//-----| fredrik@kaupangstudios.com ------- www.kaupangstudios.com |---\\
//---------------------------------------------------------------------\\

#pragma strict

private var isGameOver : boolean;

private var isAdjusting : boolean;
var money_text : TextMesh;

private var temp_money : int;
var money : int;

var happiness : int;

private var check_timer : float;
private var check_interval : float = 0.1;

private var smiley_anim : String[] = ["Smiley/Smiley_0", "Smiley/Smiley_1", "Smiley/Smiley_2"];
private var smiley_tex : Texture2D[];

var smiley : Transform;

var farm : HH_Farm;

var timer_text : TextMesh;

var timer : float;
var minutes : int;

function Awake () {
	smiley_tex = new Texture2D[smiley_anim.Length];

	for (var i:int=0; i<smiley_anim.Length; i++) {
		smiley_tex[i] = Resources.Load(smiley_anim[i]) as Texture2D;
	}
	
	money_text.renderer.material.color = Color.black;
	timer_text.renderer.material.color = Color.black;
	
	money = farm.GetMoney();
	money_text.text = "" + money;
}

var ourTime : String;
function Update () {
	if (isGameOver) return;

	check_timer += Time.deltaTime;
	
	if (check_timer > check_interval && !isAdjusting) {
		check_timer = 0;
		
		temp_money = farm.GetMoney();
		if (temp_money != money) {
			isAdjusting = true;

			SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[0], SFXManager.AUDIO_VOLUMES[0]);
			SetMoney(temp_money);
		}
		
		happiness = farm.GetHappiness();
		
		
		SetHappiness(happiness);
	}
	
	timer += Time.deltaTime;
	if (timer >= 60) {
		timer = 0;
		minutes ++;
	}
	
	ourTime = "" + ourTime.Format("{00:00:}", minutes) + ourTime.Format("{00:00}",timer);
	timer_text.text = ourTime;
}

function SetMoney (_temp_money : int) {
	//SFX for cash
	
	//Adjust cash dynamically
	/*if (_temp_money > money) {
		
		while (temp_money < money) {
			temp_money++;
			money_text.text = "" + temp_money;
		
			yield WaitForSeconds(0.02);
		}
	} else {
		while (temp_money > money) {
			temp_money--;
			money_text.text = "" + temp_money;
		
			yield WaitForSeconds(0.02);
		}
	}*/

	money = temp_money;
	money_text.text = "" + money;
	
	isAdjusting = false;
	
	if (money <= 0) {
		SetGameOver();
	}
}

function SetHappiness (_happiness : int) {
	if (_happiness < 40) {
		smiley.gameObject.renderer.material.mainTexture = smiley_tex[0];
	} else if (_happiness < 60) {
		smiley.gameObject.renderer.material.mainTexture = smiley_tex[1];
	} else {
		smiley.gameObject.renderer.material.mainTexture = smiley_tex[2];
	}
}

var GameOverScreen : GameObject;
var game_over_timer_text : TextMesh;

function SetGameOver () {
	
	game_over_timer_text.renderer.material.color = Color.black;
	
	isGameOver = true;
	GameOverScreen.SetActiveRecursively(true);
	
	//Game OVer cue
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[16], SFXManager.AUDIO_VOLUMES[16]);
	
	//Fade out audio
	iTween.AudioTo(GameObject.Find("BGaudio"),{"volume":0.0,"time":1.0});
	
	game_over_timer_text.text = ourTime;
}