//---------------------------------------------------------------------\\
//   ___            _                _ __    _ __                      \\
//  / __|    __    | |_     _  _    | '_ \  | '_ \   ___    _ _        \\
//  \__ \   / _|   | ' \   | +| |   | .__/  | .__/  / -_)  | ' \       \\
//  |___/   \__|_  |_||_|   \_,_|   |_|__   |_|__   \___|  |_||_|      \\
//---------------------------------------------------------------------\\
//-----| Copyright (c) 2013 Fredrik Kaupang (Kaupang Studios, Inc) |---\\
//-----| fredrik@kaupangstudios.com ------- www.kaupangstudios.com |---\\
//---------------------------------------------------------------------\\

#pragma strict

private var hasMission : boolean;
private var mission_check_timer : float;

var bee_number : int;
private var bee_circle_path : iTweenPath;

private var inputManager : InputManager;

private var bee_qty : int = 10;
var target : int = -1;

//var path : Transform[];

//--------------------------------------------\\
//--------------ANIM-VARIABLES----------------\\
//--------------------------------------------\\
private var animframes : String[] = [	"Bee/Bee_side0001", "Bee/Bee_side0002", "Bee/Bee_side0003", "Bee/Bee_side0004",
										"Bee/Bee_sick_side0001", "Bee/Bee_sick_side0002", "Bee/Bee_sick_side0003", "Bee/Bee_sick_side0004",
										"Bee/Dead_bee0001", "Bee/Dead_bee0002", "Bee/Dead_bee0003", "Bee/Dead_bee0004", "Bee/Dead_bee0005"];

private var normal_textures : Texture2D[];
private var sick_textures : Texture2D[];
private var dead_textures : Texture2D[];

var anim_state : int;

private var anim_timer : float;
private var ANIM_STEP : float;

private var ANIM_FPS : int = 24;

//--------------------------------------------\\
//----------------FLY-PATHS-------------------\\
//--------------------------------------------\\
var fly_out_paths : iTweenPath[];
var flyhome_paths : iTweenPath[];
var flyhome_sick_paths : iTweenPath[];	

//1 = Flying to field, 2 = harvesting, 3 = returning home
var state : int = 0;

//0 = normal, 1 = infected, 2 = dead
var condition : int;

var bee_transform : Transform;

function Awake () {
	inputManager = (GameObject.Find("InputUIText").GetComponent("InputManager") as InputManager);

	normal_textures = new Texture2D[4];
	sick_textures = new Texture2D[4];
	dead_textures = new Texture2D[4];

	for (var i:int=0; i<4; i++) {
		normal_textures[i] = Resources.Load(animframes[i]) as Texture2D;
		sick_textures[i] = Resources.Load(animframes[i+4]) as Texture2D;
		dead_textures[i] = Resources.Load(animframes[i+8]) as Texture2D;
	}
	
	ANIM_STEP = 1.0 / ANIM_FPS;
	
	fly_out_paths = new iTweenPath[18];
	flyhome_paths = new iTweenPath[18];
	for (i=0; i<18; i++) {
		fly_out_paths[i] = (GameObject.Find("fly_out_path_" + i).GetComponent("iTweenPath") as iTweenPath);
		flyhome_paths[i] = (GameObject.Find("fly_home_path_" + i).GetComponent("iTweenPath") as iTweenPath);
	}
	
	bee_transform.renderer.material.renderQueue = 3500 + bee_number;
	
	//Find our idle path
	bee_circle_path = (GameObject.Find("bee_circle_path_" + bee_number).GetComponent("iTweenPath") as iTweenPath);
}


function Start () {
	yield WaitForSeconds (bee_number);
	
	iTween.MoveTo(gameObject,{"path":bee_circle_path.GetPath("bee_circle_path_" + bee_number),"time":20,"oncomplete":"RandomIdleAnim","oncompletetarget":gameObject,"easetype":"easeInOutSine"});	
}

function RandomIdleAnim () {
	var randomNumber : int = Random.Range(0,5);
	bee_circle_path = (GameObject.Find("bee_circle_path_" + randomNumber).GetComponent("iTweenPath") as iTweenPath);
	
	iTween.MoveTo(gameObject,{"path":bee_circle_path.GetPath("bee_circle_path_" + randomNumber),"time":20,"oncomplete":"RepeatIdleAnim","oncompletetarget":gameObject,"easetype":"easeInOutSine"});	
}

function RepeatIdleAnim () {
	yield;
	RandomIdleAnim();
}

function Update () {

	anim_timer += Time.deltaTime;
	mission_check_timer += Time.deltaTime;
	
	if (!hasMission && mission_check_timer >= 1 && target == -1) {
		mission_check_timer = 0;
		
		if (Mathf.Floor(hive_script.bee_qty / 10) > bee_number) {
			CheckTarget();
		}
	}

	if (anim_timer > ANIM_STEP) {
		anim_timer = 0;
		
		if (anim_state < normal_textures.Length - 1) {
			
			bee_transform.gameObject.renderer.material.mainTexture = GetAnimTexture(condition, anim_state);
			anim_state++;
		} else {
			bee_transform.gameObject.renderer.material.mainTexture = GetAnimTexture(condition, anim_state);
			anim_state = 0;
		}
	}
}

function GetAnimTexture (_cond : int, _st : int) : Texture2D {
	var tempTex : Texture2D;
	
	if (_cond == 0) {
		tempTex = normal_textures[_st];
	} else if (_cond == 1) {
		tempTex = sick_textures[_st];
	} else if (_cond == 2) {
		tempTex = dead_textures[_st];
	}

	return tempTex;
}

function SetBeeStats (_qty : int, _target : int) {
	bee_qty = _qty;
}

function FlyOut (_target : int) {
	//Get the Complete target, and funtion
	var tempRandom : int = Random.Range(0,4);
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[10 + tempRandom], SFXManager.AUDIO_VOLUMES[10 + tempRandom]);
	
	iTween.MoveTo(gameObject,{"path":fly_out_paths[_target].GetPath("fly_out_path_" + _target),"time":5,"oncomplete":"Harvest","oncompletetarget":gameObject,"oncompleteparams":_target,"easetype":"easeInOutSine"});	
}	

function Harvest (_target : int) {	
	
	yield WaitForSeconds(0.5);
	
	var honey_val : int = (GameObject.Find("crop_" + _target).GetComponent("HH_Crop") as HH_Crop).Pollinate();
	
	if (honey_val == -1) {
		//Set poison. Swap to poison texture
		condition = 1;

	} else if (honey_val > 0) {
		SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[4], SFXManager.AUDIO_VOLUMES[4]);
	}
	
	FlyHome(_target, honey_val);
}

function FlyHome (_target : int, _honey_val : int) {
	iTween.MoveTo(gameObject,{"path":flyhome_paths[_target].GetPath("fly_home_path_" + _target),"time":(_honey_val > 0 ? 5 : 7),"oncomplete":"MissionComplete","oncompleteparams":_honey_val,"oncompletetarget":gameObject,"easetype":"easeInOutSine"});	
}

function MissionComplete (_honey_val : int) {
	BeeReturn(_honey_val);
	
	if (_honey_val == -1) {
		iTween.ShakePosition(GameObject.Find("hive"), {"time":1,"x":0.2,"y":0.2});
		SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[15], SFXManager.AUDIO_VOLUMES[15]);
	}
	
	RandomIdleAnim();
}

function CheckTarget () {
	var tempTarget : int = inputManager.GetNextInQueue(bee_number);
	
	if (tempTarget < 0) {
		return;
	}
	
	hasMission = true;
	target = tempTarget;

	FlyOut(target);
}

function SplatBee () {
	condition = 2;
	
	iTween.Stop(gameObject);
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[5], SFXManager.AUDIO_VOLUMES[5]);
	
	yield WaitForSeconds(2);
	
	ResetBee();
}

function ResetBee () {
	bee_transform.gameObject.renderer.material.mainTexture = normal_textures[0];
	condition = 0;
	
	if (target != -1) inputManager.cropStatuses[target] = 0;
	target = -1;
	hasMission = false;
	
	transform.position = Vector2(0, -3.2);
}

function BeeReturn (_honey_val : int) {
	(GameObject.Find("hive").GetComponent("hive_script") as hive_script).BeeReturn(_honey_val, condition);
	
	bee_transform.gameObject.renderer.material.mainTexture = normal_textures[0];
	condition = 0;
	
	inputManager.cropStatuses[target] = 0;
	target = -1;
	hasMission = false;
	
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[3], SFXManager.AUDIO_VOLUMES[3]);
	
	inputManager.SetQueueDisplay();
	yield;
}