using UnityEngine;
using System.Collections;

public class HH_Crop : MonoBehaviour {
	                            
	public static float cycleTime = 15.0F;
	
	public enum Type {Wheat,Tomato,Watermelon,Clover};  
	public enum Stage {Empty,Flower,Ripe,Withered};
	public enum Disease {None,Fungus,Bugs,Pesticide};
	
	public static int[] HONEY = new int[] {5,10,10,15},
	                    MONEY = new int[] {7,5,4,2};
	
	public int CROP_SUCCESS_HAPPINESS = 5,
	           CROP_FAILURE_HAPPINESS = -10,
	           CROP_FAILURE_MONEY = -10;
	
	public Material emptyMaterial;
	public Material[] stageMaterials;
	
	public static float DISEASE_CHANCE = 0.3F,
	                    SPRAY_CHANCE = 0.8F;
	
	public GameObject diseasePrefab;
    public Material[] diseaseMaterials;
	
	void Start () {
		if(Random.value > 0.5F) {
			if(Random.value > 0.5F)
				type = Type.Wheat;
			else
				type = Type.Tomato;
		}
		else {
			if(Random.value > 0.5F)
				type = Type.Watermelon;
			else
				type = Type.Clover;
		}
		stage = Stage.Empty;
		UpdateMaterial();
		nextStageTime = Time.realtimeSinceStartup+Random.Range(5.0F,10.0F);
	}
	
	void Update () {
		float time = Time.realtimeSinceStartup;
		if(time > nextStageTime) {
			SwitchStage();
			
			//if(Random.value > 0.5F)
			//	Pollinate();
			
			nextStageTime = time+cycleTime;
		}
	}
	
	public bool IsPollinateable() {
		return !pollinated && stage == Stage.Flower;
	}
	
	// returns honey from pollination (zero honey mean not pollenatable or already pollinated and -1 means sick)
	public int Pollinate() {
		if(IsPollinateable()) {
			pollinated = true;  // we still pollenate even if it is diseased but no honey
			if(IsDiseased())
				return -1;
			else 
				return HONEY[(int)type];
		}
		else
			return 0;
	}
	
	private void SwitchStage() {
		if(stage == Stage.Empty) {
			if(Random.value > 0.75F) {  // 25% chance farmer will plant each cycle
				stage = Stage.Flower;
				if(Random.value > 1.0F-DISEASE_CHANCE)  // disease on flower (fungus or bugs)
					SetDisease(GetRandomDisease());
			}
		}
		else if(stage == Stage.Flower) {
			if(pollinated) {
				stage = Stage.Ripe;
				if(IsDiseased()) {
					//if(Random.value > 1.0F-SPRAY_CHANCE)  // spray pesticide on fruit
						SetDisease(Disease.Pesticide);
				}
			}
			else {
				stage = Stage.Withered;
				SetDisease(Disease.None);
			}
		}
		else if(stage == Stage.Ripe || stage == Stage.Withered) {
			if(Random.value > 0.25F)  // 75% chance farmer will harvest every cycle
				Harvest();
		}
		UpdateMaterial();
	}
	
	private bool IsHarvestable() {
		return (pollinated && stage == Stage.Ripe) || stage == Stage.Withered;
	}
	
	// returns money from harvest (0 if not harvestable yet or already harvested, negitive money if withered)
	private bool Harvest() {
		if(IsHarvestable()) {
			int happiness,
			    money;
			if(stage == Stage.Ripe) {
				pollinated = false;
				happiness = CROP_SUCCESS_HAPPINESS;
				money = MONEY[(int)type];
			}
			else {
				happiness = CROP_FAILURE_HAPPINESS;
				money = CROP_FAILURE_MONEY;
			}
			HH_Farm farm = transform.parent.gameObject.GetComponent<HH_Farm>();
			farm.AdjustHappiness(happiness);
			farm.AdjustMoney(money);
			stage = Stage.Empty;
			SetDisease(Disease.None);
			UpdateMaterial();
			return true;
		}
		else
			return false;
	}
	
	private bool IsDiseased() {
		return disease != Disease.None;
	}
	
	private Disease GetRandomDisease() {
		//if(Random.value > 0.5F)
			return Disease.Fungus;
		//else
			//return Disease.Bugs;
	}
	
	private void SetDisease(Disease disease) {
		if((!IsDiseased() || disease == Disease.Pesticide) && disease != Disease.None) {
			if(diseaseObject == null) {
				diseaseObject = (GameObject)Instantiate(diseasePrefab,transform.localPosition+new Vector3(0.0F,1.0F,-0.1F),transform.localRotation);
				diseaseObject.transform.parent = transform.parent;
				diseaseObject.name = transform.name+"_disease";
			}
			if(!diseaseObject.active)
				diseaseObject.active = true;
			diseaseObject.renderer.material = diseaseMaterials[((int)disease)-1];
		}
		else {
			if(diseaseObject != null)
				diseaseObject.active = false;
		}
		this.disease = disease;
	}
	
	private void UpdateMaterial() {
		MeshRenderer meshRenderer = gameObject.GetComponent<MeshRenderer>();
		if(stage == Stage.Empty)
			meshRenderer.material = emptyMaterial;
		else
			meshRenderer.material = stageMaterials[(((int)type)*3)+(((int)stage)-1)];
	}
	
	private Type type;
	private Stage stage;
	
	private Disease disease;
	private GameObject diseaseObject;
	
	private bool pollinated;
	
	private float nextStageTime;
}
