//---------------------------------------------------------------------\\
//   ___            _                _ __    _ __                      \\
//  / __|    __    | |_     _  _    | '_ \  | '_ \   ___    _ _        \\
//  \__ \   / _|   | ' \   | +| |   | .__/  | .__/  / -_)  | ' \       \\
//  |___/   \__|_  |_||_|   \_,_|   |_|__   |_|__   \___|  |_||_|      \\
//---------------------------------------------------------------------\\
//-----| Copyright (c) 2013 Fredrik Kaupang (Kaupang Studios, Inc) |---\\
//-----| fredrik@kaupangstudios.com ------- www.kaupangstudios.com |---\\
//---------------------------------------------------------------------\\

#pragma strict

private var FIELDS : int = 18;

var cropStatusText : TextMesh[];

//0 = available, 1 = in queue, 2 = active target
var cropStatuses : int[];

private var MAX_QUEUES : int = 5;
var queue_order : int[];

//Raycasting
private var ray : Ray;
private var hit : RaycastHit;

var target : Transform;

private var field_anim : String[] = ["Target/Target_0", "Target/Target_1", "Target/Target_2", "Target/Target_3", "Target/Target_4", "Target/Target_5", "Target/Target_empty"];
private var field_ui_textures : Texture2D[];
private var field_ui : Transform[];

function Awake () {
	cropStatusText = new TextMesh[FIELDS];
	cropStatuses = new int[FIELDS];
	
	queue_order = new int[MAX_QUEUES];
	queue_order = [-1,-1,-1,-1,-1];
	
	field_ui_textures = new Texture2D[field_anim.Length];
	for (var i:int=0; i<field_anim.Length; i++) {
		field_ui_textures[i] = Resources.Load(field_anim[i]) as Texture2D;
	}
	
	field_ui = new Transform[FIELDS];
	for (i=0; i<FIELDS; i++) {
		var field_ui_GO : GameObject = Instantiate(Resources.Load("field_ui") as GameObject, Vector3(-2.7 + ((i%9)*0.73), (Mathf.Floor(i/9) == 0 ? 2.1 : 1.35), -5), Quaternion.Euler(-90,0,0));
		field_ui[i] = field_ui_GO.transform;
		field_ui[i].name = "field_ui_" + i;
		field_ui[i].parent = transform;
		field_ui[i].gameObject.renderer.material.mainTexture = field_ui_textures[6];
	}
	
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[15], SFXManager.AUDIO_VOLUMES[15]);
	
	SetQueueDisplay();
}

function Update () {
	if (Input.GetMouseButtonDown(0)) {
		ray = Camera.main.ScreenPointToRay (Input.mousePosition);
		if (Physics.Raycast (ray, hit, 100)) {
			target = hit.transform;

			if (target.name == "bee") {
				target.SendMessageUpwards("SplatBee", SendMessageOptions.DontRequireReceiver);
			} else {
				for (var i:int=0; i<FIELDS; i++) {
					if (target.name == "crop_" + i) {
						AddInQueue(i);
					}
				}
			}
		}
	}
}

function AddInQueue (_field : int) {
	//If active, return
	if (cropStatuses[_field] == 2) {
		SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[6], SFXManager.AUDIO_VOLUMES[6]);
		return;
	}
	
	
	//If it's already in queue, deselect
	for (var i:int=0; i<queue_order.Length; i++) {
		if (queue_order[i] == _field) {
			SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[7], SFXManager.AUDIO_VOLUMES[7]);			
			RemoveFromQueue(_field, i);
			return;
		}
	}
	
	//If queue is full, return
	if (queue_order[queue_order.Length-1] != -1) {
		SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[8], SFXManager.AUDIO_VOLUMES[8]);
		return;
	}
	
	//Else, place entry in queue
	AddToQueue(_field);
	SFXManager.PlayAudio(SFXManager.AUDIO_NAMES[6], SFXManager.AUDIO_VOLUMES[6]);
}

function AddToQueue (_field : int) {
	for (var i:int=0; i<queue_order.Length; i++) {
		if (queue_order[i] == -1) {
			queue_order[i] = _field;
			
			cropStatuses[queue_order[i]] = 1;
			break;
		}	
	}
	
	SetQueueDisplay();
}

function RemoveFromQueue (_field : int, _index : int) {	
	cropStatuses[queue_order[_index]] = 0;
	queue_order[_index] = -1;
	
	for (var i:int=_index+1; i<queue_order.Length; i++) {
		queue_order[i-1] = queue_order[i];	
	}
	queue_order[queue_order.Length-1] = -1;
	
	SetQueueDisplay();
}

function GetNextInQueue (_bee : int) : int {

	if (queue_order[0] < 0) {
		return - 1;
	}
	
	var tempQueue : int = queue_order[0];
	cropStatuses[queue_order[0]] = 2;

	for (var i:int=0; i<queue_order.Length - 1; i++) {
		queue_order[i] = queue_order[i+1];
	}
	queue_order[queue_order.Length - 1] = -1;
	
	SetQueueDisplay();
	
	return tempQueue;
}

function SetQueueDisplay () {
	//----------------------------------------\\
	
	for (var i:int=0; i<FIELDS; i++) {
		field_ui[i].gameObject.renderer.material.mainTexture = field_ui_textures[6];
		
		if (cropStatuses[i] == 2) {
			field_ui[i].gameObject.renderer.material.mainTexture = field_ui_textures[0];
		}
	}

	//----------------------------------------\\
	
	for (i=0; i<queue_order.Length; i++) {
		if (queue_order[i] >= 0) {
			field_ui[queue_order[i]].gameObject.renderer.material.mainTexture = field_ui_textures[i+1];
			
			cropStatuses[queue_order[i]] = 1;
		}
	}
}